summaryrefslogtreecommitdiff
path: root/wizards/com/sun/star/wizards/ui/event/DataAware.java
diff options
context:
space:
mode:
Diffstat (limited to 'wizards/com/sun/star/wizards/ui/event/DataAware.java')
-rw-r--r--wizards/com/sun/star/wizards/ui/event/DataAware.java3
1 files changed, 2 insertions, 1 deletions
diff --git a/wizards/com/sun/star/wizards/ui/event/DataAware.java b/wizards/com/sun/star/wizards/ui/event/DataAware.java
index b81b8e71bcdb..62eaaf657447 100644
--- a/wizards/com/sun/star/wizards/ui/event/DataAware.java
+++ b/wizards/com/sun/star/wizards/ui/event/DataAware.java
@@ -31,6 +31,7 @@ import java.lang.reflect.Method;
import java.util.Arrays;
import java.util.Collection;
import java.util.Iterator;
+import com.sun.star.wizards.common.PropertyNames;
/**
* @author rpiterman
@@ -275,7 +276,7 @@ public abstract class DataAware {
/**
* creates a PropertyValue for the property with
* the given name, of the given JavaBean object.
* @param propertyName the property to access. Must be a Cup letter (e.g. "Name" for getName() and setName("..."). )
* @param propertyOwner the object which "own" or "contains" the property.
*/
public PropertyValue(String propertyName, Object propertyOwner) {
@@ -275,7 +276,7 @@ public abstract class DataAware {
* creates a PropertyValue for the property with
* the given name, of the given JavaBean object.
- * @param propertyName the property to access. Must be a Cup letter (e.g. "Name" for getName() and setName("..."). )
+ * @param propertyName the property to access. Must be a Cup letter (e.g. PropertyNames.PROPERTY_NAME for getName() and setName("..."). )
* @param propertyOwner the object which "own" or "contains" the property.
*/